==> kdebase-4.4.3.tar.xz: kdebase-4.4.3/apps/dolphin/src/settings/servicessettingspage.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Peter Penz <peter.penz@gmx.at>                  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/
#ifndef SERVICESSETTINGSPAGE_H
#define SERVICESSETTINGSPAGE_H

#include <settings/settingspagebase.h>

class QListWidget;

/**
 * @brief Page for the 'Services' settings of the Dolphin settings dialog.
 */
class ServicesSettingsPage : public SettingsPageBase
{
    Q_OBJECT

public:
    ServicesSettingsPage(QWidget* parent);
    virtual ~ServicesSettingsPage();

    /** @see SettingsPageBase::applySettings() */
    virtual void applySettings();

    /** @see SettingsPageBase::restoreDefaults() */
    virtual void restoreDefaults();

protected:
    virtual bool event(QEvent* event);

private slots:
    /**
     * Loads locally installed services.
     */
    void loadServices();

    bool isInServicesList(const QString& service) const;

private:
    bool m_initialized;
    QListWidget* m_servicesList;
};

#endif

==> kdebase-4.5.5.tar.xz: kdebase-4.5.5/apps/dolphin/src/settings/servicessettingspage.h <==
/***************************************************************************
 *   Copyright (C) 2009-2010 by Peter Penz <peter.penz@gmx.at>             *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
 ***************************************************************************/
#ifndef SERVICESSETTINGSPAGE_H
#define SERVICESSETTINGSPAGE_H

#include <settings/settingspagebase.h>

#include <QMap>
#include <QString>

class QCheckBox;
class QGroupBox;
class QListWidget;

/**
 * @brief Page for the 'Services' settings of the Dolphin settings dialog.
 */
class ServicesSettingsPage : public SettingsPageBase
{
    Q_OBJECT

public:
    ServicesSettingsPage(QWidget* parent);
    virtual ~ServicesSettingsPage();

    /** @see SettingsPageBase::applySettings() */
    virtual void applySettings();

    /** @see SettingsPageBase::restoreDefaults() */
    virtual void restoreDefaults();

protected:
    virtual void showEvent(QShowEvent* event);

private slots:
    /**
     * Loads locally installed services.
     */
    void loadServices();

    /**
     * Loads installed version control systems.
     */
    void loadVersionControlSystems();

    bool isInServicesList(const QString& service) const;

private:
    bool m_initialized;
    QListWidget* m_servicesList;
    QGroupBox* m_vcsGroupBox;
    QMap<QString, QCheckBox*> m_vcsPluginsMap;
    QStringList m_enabledVcsPlugins;
};

#endif
